## 0.6.1 (2024-03-25)

### Fix

- updated CI pipeline

## 0.6.0 (2024-03-24)

### Feat

- updated version in changelog and pyproject for consistent migration
- ready for beta release

## 0.5.0 (2024-03-24)

### Feat

- migrated repo from private
